@@ -1,8 +1,8 @@
-import re
 from urlparse import urlsplit
 from xmlrpclib import ServerProxy, Fault, ProtocolError
 from urllib2 import urlopen
 from urlparse import urljoin
+import re
 import socket
 import threading
 import logging
@@ -14,7 +14,7 @@ from django.conf import settings
 from django.core.urlresolvers import reverse
 
 from pingback.models import PingbackClient, DirectoryPing
-from pingback.exceptions import PingbackNotConfigured, PingbackError
+from pingback.exceptions import PingbackError
 
 class PingBackThread(threading.Thread):
     def __init__(self, instance, url, links):
@@ -40,11 +40,11 @@ class PingBackThread(threading.Thread):
                         server = ServerProxy(server_url)
                         try:
                             result = server.pingback.ping(self.url, link)
-                        except Exception, e:
+                        except Exception:
                             pingback.success = False
                         else:
                             pingback.success = not PingbackError.is_error(result)
-                except (IOError, ValueError, Fault), e:
+                except (IOError, ValueError, Fault):
                     pass
                 pingback.save()
         socket.setdefaulttimeout(None)
@@ -104,7 +104,9 @@ def ping_external_links(content_attr=None,
             return path_e != path_i
 
         soup = BeautifulSoup(content)
-        links = [a['href'] for a in soup.findAll('a') if is_external(a['href'], url)]
+        # a.has_key('href') != 'href' in a for BeautifulSoup
+        links = [a['href'] for a in soup.findAll('a')
+                 if a.has_key('href') and is_external(a['href'], url)]
 
         log.debug('URL %s, pinging all these links: %r' % (url, links))
         pbt = PingBackThread(instance=instance, url=url, links=links)
@@ -112,9 +114,7 @@ def ping_external_links(content_attr=None,
     return execute_links_ping
 
 
-def ping_directories(content_attr=None,
-                     content_func=None,
-                     url_attr='get_absolute_url',
+def ping_directories(url_attr='get_absolute_url',
                      filtr=lambda x: True,
                      feed_url_fun=lambda x: reverse('feed', args=['blog'])):
     """Ping blog directories
@@ -130,8 +130,6 @@ def ping_directories(content_attr=None,
       - `filtr` - function to filter out instances. False will interrupt ping.
       - `feed_url_fun` - function to find feed url
     """
-    assert(content_attr or content_func)
-
     def execute_dirs_ping(instance, **kwargs):
         log = logging.getLogger('pingback')
         log.debug('pinging directories')
@@ -139,10 +137,6 @@ def ping_directories(content_attr=None,
         if not filtr(instance):
             return
         site = getattr(instance, 'site', Site.objects.get_current())
-        if content_attr is None:
-            content = content_func(instance)
-        else:
-            content = maybe_call(getattr(instance, content_attr))
         protocol = getattr(settings, 'SITE_PROTOCOL', 'http')
         url = maybe_call(getattr(instance, url_attr))
         feed_url = feed_url_fun(instance)
@@ -161,10 +155,10 @@ def ping_directories(content_attr=None,
                 try:
                     q = server.weblogUpdates.extendedPing(site.name, blog_url, url, feed_url)
                 #TODO: Find out name of exception :-)
-                except Exception, ex:
+                except Exception:
                     try:
                         q = server.weblogUpdates.ping(site.name, blog_url, url)
-                    except ProtocolError, e:
+                    except ProtocolError:
                         log.exception('protocol error during directory ping %r' % directory_url)
                         ping.success = False
                         ping.save()
@@ -174,7 +168,7 @@ def ping_directories(content_attr=None,
                     log.error('flerror: %s' % q.get('message', 'no message'))
                 else:
                     ping.success = True
-            except (IOError, ValueError, Fault, socket.error), e:
+            except (IOError, ValueError, Fault, socket.error):
                 log.exception('error during directory ping %r' % directory_url)
             ping.save()
     return execute_dirs_ping
