@@ -1,4 +1,6 @@
 from django.core import urlresolvers
+from pingback import ping_func
+from django_xmlrpc import xmlrpcdispatcher
 
 class PingbackMiddleware(object):
     def __init__(self):
@@ -9,6 +11,9 @@ class PingbackMiddleware(object):
             # settings.ROOT_URLCONF
             self.xmlrpc_url = None
 
+        # register this method in the dispatcher
+        xmlrpcdispatcher.register_function(ping_func, 'pingback.ping')
+
     def process_response(self, request, response):
         if response.status_code == 200 and self.xmlrpc_url:
             response['X-Pingback'] = request.build_absolute_uri(self.xmlrpc_url)
